package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Feb 10, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
SchemaImport string `json:"schema_import"`
WriteToPath string `json:"write_to_path"`
ModelName string `json:"model_name"`
LowerModelName string `json:"lower_model_name"`
Fields []Desc `json:"fields"`
}
type Desc struct {
LowerName string `json:"lower_name"`
PublicName string `json:"public_name"`
HasValidators bool `json:"has_validators"`
Type string `json:"type"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.